# Dummy file :)
package Task::POE::All;
use strict;
use warnings;

use vars qw( $VERSION );
BEGIN {
	$VERSION = '1.00';
}

# End of module
1;
__END__

=head1 NAME

Task::POE::All - Installs all the modules in the POE::* namespace ( latest version )

=head1 DESCRIPTION

This module will use CPANPLUS to retrieve all the modules under the POE::* namespace and install them.

=head1 AUTHOR

Apocalypse E<lt>apocal@cpan.orgE<gt>

Big thanks also goes to KANE + BiNGOs for helping me navigate CPANPLUS::Backend!

=head1 COPYRIGHT AND LICENSE

Copyright 2008 by Apocalypse

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
